@@ -54,9 +54,6 @@
 #include "../e-meeting-store.h"
 #include "../e-meeting-list-view.h"
 
-/* backward-compatibility cruft */
-#include "e-util/gtk-compat.h"
-
 #define TASK_PAGE_GET_PRIVATE(obj) \
 	(G_TYPE_INSTANCE_GET_PRIVATE \
 	((obj), TYPE_TASK_PAGE, TaskPagePrivate))
@@ -732,8 +729,10 @@ task_page_fill_widgets (CompEditorPage *page, ECalComponent *comp)
 				g_signal_handlers_block_by_func (gtk_bin_get_child (GTK_BIN (priv->organizer)), organizer_changed_cb, tpage);
 
 				if (!priv->user_org) {
-					gtk_list_store_clear (GTK_LIST_STORE (gtk_combo_box_get_model (GTK_COMBO_BOX (priv->organizer))));
-					gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (priv->organizer), string);
+					GtkTreeModel *model = gtk_combo_box_get_model (GTK_COMBO_BOX (priv->organizer));
+
+					gtk_list_store_clear (GTK_LIST_STORE (model));
+					e_dialog_append_list_store_text (model, 0, string);
 					gtk_combo_box_set_active (GTK_COMBO_BOX (priv->organizer), 0);
 					gtk_editable_set_editable (GTK_EDITABLE (gtk_bin_get_child (GTK_BIN (priv->organizer))), FALSE);
 				} else {
@@ -1421,7 +1420,7 @@ get_widgets (TaskPage *tpage)
 
 	priv->organizer = e_builder_get_widget (priv->builder, "organizer");
 	gtk_list_store_clear (GTK_LIST_STORE (gtk_combo_box_get_model (GTK_COMBO_BOX (priv->organizer))));
-	gtk_combo_box_set_entry_text_column (GTK_COMBO_BOX_ENTRY (priv->organizer), 0);
+	gtk_combo_box_set_entry_text_column (GTK_COMBO_BOX (priv->organizer), 0);
 
 	priv->invite = e_builder_get_widget (priv->builder, "invite");
 	priv->add = e_builder_get_widget (priv->builder, "add-attendee");
@@ -2089,9 +2088,10 @@ task_page_construct (TaskPage *tpage, EMeetingStore *model, ECal *client)
 
 	if (priv->address_strings) {
 		GList *l;
+		GtkTreeModel *model = gtk_combo_box_get_model (GTK_COMBO_BOX (priv->organizer));
 
 		for (l = priv->address_strings; l; l = l->next)
-			gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (priv->organizer), l->data);
+			e_dialog_append_list_store_text (model, 0, l->data);
 
 		gtk_combo_box_set_active (GTK_COMBO_BOX (priv->organizer), 0);
 
