@@ -34,7 +34,6 @@
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
 #include <gdk/gdkkeysyms.h>
-#include <e-util/e-binding.h>
 #include <table/e-table-memory-store.h>
 #include <table/e-cell-checkbox.h>
 #include <table/e-cell-toggle.h>
@@ -61,7 +60,7 @@
 #include "goto.h"
 #include "misc.h"
 
-static void      e_cal_list_view_destroy                (GtkObject *object);
+static void      e_cal_list_view_dispose                (GObject *object);
 
 static GList    *e_cal_list_view_get_selected_events    (ECalendarView *cal_view);
 static gboolean  e_cal_list_view_get_selected_time_range (ECalendarView *cal_view, time_t *start_time, time_t *end_time);
@@ -83,16 +82,16 @@ G_DEFINE_TYPE (ECalListView, e_cal_list_view, E_TYPE_CALENDAR_VIEW)
 static void
 e_cal_list_view_class_init (ECalListViewClass *class)
 {
-	GtkObjectClass *object_class;
+	GObjectClass *object_class;
 	GtkWidgetClass *widget_class;
 	ECalendarViewClass *view_class;
 
-	object_class = (GtkObjectClass *) class;
+	object_class = (GObjectClass *) class;
 	widget_class = (GtkWidgetClass *) class;
 	view_class = (ECalendarViewClass *) class;
 
 	/* Method override */
-	object_class->destroy		= e_cal_list_view_destroy;
+	object_class->dispose		= e_cal_list_view_dispose;
 
 	widget_class->popup_menu = e_cal_list_view_popup_menu;
 
@@ -174,7 +173,7 @@ setup_e_table (ECalListView *cal_list_view)
 
 	/* Create the header columns */
 
-	extras = e_table_extras_new();
+	extras = e_table_extras_new ();
 
 	/* Normal string fields */
 
@@ -192,21 +191,27 @@ setup_e_table (ECalListView *cal_list_view)
 		      "bg_color_column", E_CAL_MODEL_FIELD_COLOR,
 		      NULL);
 
-	e_mutual_binding_new (
+	g_object_bind_property (
 		model, "timezone",
-		cell, "timezone");
+		cell, "timezone",
+		G_BINDING_BIDIRECTIONAL |
+		G_BINDING_SYNC_CREATE);
 
-	e_mutual_binding_new (
+	g_object_bind_property (
 		model, "use-24-hour-format",
-		cell, "use-24-hour-format");
+		cell, "use-24-hour-format",
+		G_BINDING_BIDIRECTIONAL |
+		G_BINDING_SYNC_CREATE);
 
 	popup_cell = e_cell_date_edit_new ();
 	e_cell_popup_set_child (E_CELL_POPUP (popup_cell), cell);
 	g_object_unref (cell);
 
-	e_mutual_binding_new (
+	g_object_bind_property (
 		model, "use-24-hour-format",
-		popup_cell, "use-24-hour-format");
+		popup_cell, "use-24-hour-format",
+		G_BINDING_BIDIRECTIONAL |
+		G_BINDING_SYNC_CREATE);
 
 	e_table_extras_add_cell (extras, "dateedit", popup_cell);
 	cal_list_view->dates_cell = E_CELL_DATE_EDIT (popup_cell);
@@ -279,8 +284,8 @@ setup_e_table (ECalListView *cal_list_view)
 	canvas = GNOME_CANVAS (cal_list_view->table->table_canvas);
 	style = gtk_widget_get_style (GTK_WIDGET (canvas));
 
-	style->fg [GTK_STATE_SELECTED] = style->text [GTK_STATE_NORMAL];
-	style->fg [GTK_STATE_ACTIVE]   = style->text [GTK_STATE_NORMAL];
+	style->fg[GTK_STATE_SELECTED] = style->text[GTK_STATE_NORMAL];
+	style->fg[GTK_STATE_ACTIVE]   = style->text[GTK_STATE_NORMAL];
 	gtk_widget_set_style (GTK_WIDGET (canvas), style);
 
 	/* Connect signals */
@@ -317,7 +322,7 @@ e_cal_list_view_new (ECalModel *model)
 }
 
 static void
-e_cal_list_view_destroy (GtkObject *object)
+e_cal_list_view_dispose (GObject *object)
 {
 	ECalListView *cal_list_view;
 
@@ -345,7 +350,8 @@ e_cal_list_view_destroy (GtkObject *object)
 		cal_list_view->table = NULL;
 	}
 
-	GTK_OBJECT_CLASS (e_cal_list_view_parent_class)->destroy (object);
+	if (G_OBJECT_CLASS (e_cal_list_view_parent_class)->dispose)
+		G_OBJECT_CLASS (e_cal_list_view_parent_class)->dispose (object);
 }
 
 static void
@@ -365,16 +371,6 @@ e_cal_list_view_popup_menu (GtkWidget *widget)
 	return TRUE;
 }
 
-static gboolean
-find_meeting (icalcomponent *icalcomp)
-{
-	icalproperty *prop = NULL;
-
-	prop = icalcomponent_get_first_property (icalcomp, ICAL_ATTENDEE_PROPERTY);
-
-	return prop ? TRUE: FALSE;
-}
-
 static gboolean
 e_cal_list_view_on_table_double_click (GtkWidget *table, gint row, gint col, GdkEvent *event,
 				      gpointer data)
@@ -383,8 +379,7 @@ e_cal_list_view_on_table_double_click (GtkWidget *table, gint row, gint col, Gdk
 	ECalModelComponent *comp_data;
 
 	comp_data = e_cal_model_get_component_at (e_calendar_view_get_model (E_CALENDAR_VIEW (cal_list_view)), row);
-	e_calendar_view_edit_appointment (E_CALENDAR_VIEW (cal_list_view), comp_data->client,
-					  comp_data->icalcomp, find_meeting (comp_data->icalcomp));
+	e_calendar_view_edit_appointment (E_CALENDAR_VIEW (cal_list_view), comp_data->client, comp_data->icalcomp, EDIT_EVENT_AUTODETECT);
 
 	return TRUE;
 }
