@@ -114,6 +114,12 @@ typedef struct {
 	gint event_num;
 } ECalendarViewEventData;
 
+typedef enum {
+	EDIT_EVENT_AUTODETECT,
+	EDIT_EVENT_FORCE_MEETING,
+	EDIT_EVENT_FORCE_APPOINTMENT
+} EEditEventMode;
+
 struct _ECalendarViewClass {
 	GtkTableClass parent_class;
 
@@ -163,6 +169,11 @@ const gchar *	e_calendar_view_get_default_category
 void		e_calendar_view_set_default_category
 						(ECalendarView *cal_view,
 						 const gchar *category);
+gint		e_calendar_view_get_time_divisions
+						(ECalendarView *cal_view);
+void		e_calendar_view_set_time_divisions
+						(ECalendarView *cal_view,
+						 gint time_divisions);
 void		e_calendar_view_set_status_message
 						(ECalendarView *cal_view,
 						 const gchar *message,
@@ -220,17 +231,13 @@ void		e_calendar_view_new_appointment	(ECalendarView *cal_view);
 void		e_calendar_view_edit_appointment (ECalendarView *cal_view,
 						 ECal *client,
 						 icalcomponent *icalcomp,
-						 gboolean meeting);
+						 EEditEventMode mode);
 void		e_calendar_view_open_event	(ECalendarView *cal_view);
 void		e_calendar_view_modify_and_send	(ECalComponent *comp,
 						 ECal *client,
 						 CalObjModType mod,
 						 GtkWindow *toplevel,
 						 gboolean new);
-void		e_calendar_utils_show_error_silent
-						(GtkWidget *widget);
-void		e_calendar_utils_show_info_silent
-						(GtkWidget *widget);
 
 gboolean	e_calendar_view_get_tooltips	(const ECalendarViewEventData *data);
 
