@@ -417,6 +417,9 @@ memo_table_constructed (GObject *object)
 	a11y = gtk_widget_get_accessible (GTK_WIDGET (memo_table));
 	if (a11y)
 		atk_object_set_name (a11y, _("Memos"));
+
+	if (G_OBJECT_CLASS (parent_class)->constructed)
+		G_OBJECT_CLASS (parent_class)->constructed (object);
 }
 
 static gboolean
@@ -981,12 +984,15 @@ get_selected_comp (EMemoTable *memo_table)
 static void
 memo_table_delete_selection (ESelectable *selectable)
 {
+	ECalModel *model;
 	EMemoTable *memo_table;
 	ECalComponent *comp = NULL;
 	ECalModelComponent *comp_data;
+	gboolean delete = TRUE;
 	gint n_selected;
 
 	memo_table = E_MEMO_TABLE (selectable);
+	model = e_memo_table_get_model (memo_table);
 
 	n_selected = e_table_selected_count (E_TABLE (memo_table));
 	if (n_selected <= 0)
@@ -1005,9 +1011,13 @@ memo_table_delete_selection (ESelectable *selectable)
 			comp, icalcomponent_new_clone (comp_data->icalcomp));
 	}
 
-	if (delete_component_dialog (
-		comp, FALSE, n_selected, E_CAL_COMPONENT_JOURNAL,
-		GTK_WIDGET (memo_table)))
+	if (e_cal_model_get_confirm_delete (model))
+		delete = delete_component_dialog (
+			comp, FALSE, n_selected,
+			E_CAL_COMPONENT_JOURNAL,
+			GTK_WIDGET (memo_table));
+
+	if (delete)
 		delete_selected_components (memo_table);
 
 	/* free memory */
@@ -1163,7 +1173,7 @@ e_memo_table_get_type (void)
 		};
 
 		type = g_type_register_static (
-			E_TABLE_TYPE, "EMemoTable", &type_info, 0);
+			E_TYPE_TABLE, "EMemoTable", &type_info, 0);
 
 		g_type_add_interface_static (
 			type, E_TYPE_SELECTABLE, &selectable_info);
