@@ -53,7 +53,6 @@
 #include "mail-mt.h"
 #include "mail-ops.h"
 #include "mail-tools.h"
-#include "mail-config.h"
 #include "e-mail-tag-editor.h"
 
 #include <libedataserver/e-data-server-util.h>
@@ -64,7 +63,6 @@
 #include "e-util/e-mktemp.h"
 #include "e-util/e-account-utils.h"
 #include "e-util/e-dialog-utils.h"
-#include "e-util/e-alert-activity.h"
 #include "e-util/e-alert-dialog.h"
 #include "shell/e-shell.h"
 #include "widgets/misc/e-attachment.h"
@@ -125,18 +123,24 @@ em_utils_ask_open_many (GtkWindow *parent,
  * Returns %TRUE if the user clicks Yes or %FALSE otherwise.
  **/
 gboolean
-em_utils_prompt_user (GtkWindow *parent, const gchar *promptkey, const gchar *tag, ...)
+em_utils_prompt_user (GtkWindow *parent,
+                      const gchar *promptkey,
+                      const gchar *tag,
+                      ...)
 {
 	GtkWidget *mbox, *check = NULL;
 	GtkWidget *container;
 	va_list ap;
 	gint button;
-	GConfClient *gconf = mail_config_get_gconf_client ();
+	GConfClient *client;
 	EAlert *alert = NULL;
 
-	if (promptkey
-	    && !gconf_client_get_bool (gconf, promptkey, NULL))
+	client = gconf_client_get_default ();
+
+	if (promptkey && !gconf_client_get_bool (client, promptkey, NULL)) {
+		g_object_unref (client);
 		return TRUE;
+	}
 
 	va_start (ap, tag);
 	alert = e_alert_new_valist (tag, ap);
@@ -155,10 +159,15 @@ em_utils_prompt_user (GtkWindow *parent, const gchar *promptkey, const gchar *ta
 
 	button = gtk_dialog_run ((GtkDialog *) mbox);
 	if (promptkey)
-		gconf_client_set_bool (gconf, promptkey, !gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check)), NULL);
+		gconf_client_set_bool (
+			client, promptkey,
+			!gtk_toggle_button_get_active (
+			GTK_TOGGLE_BUTTON (check)), NULL);
 
 	gtk_widget_destroy (mbox);
 
+	g_object_unref (client);
+
 	return button == GTK_RESPONSE_YES;
 }
 
@@ -265,7 +274,7 @@ static EMFilterSource em_filter_source_element_names[] = {
 /**
  * em_utils_edit_filters:
  * @parent: parent window
- * @session: an #EMailSession
+ * @backend: an #EMailBAckend
  *
  * Opens or raises the filters editor dialog so that the user may edit
  * his/her filters. If @parent is non-NULL, then the dialog will be
@@ -273,13 +282,14 @@ static EMFilterSource em_filter_source_element_names[] = {
  **/
 void
 em_utils_edit_filters (GtkWidget *parent,
-                       EMailSession *session)
+                       EMailBackend *backend)
 {
 	const gchar *config_dir;
 	gchar *user, *system;
 	EMFilterContext *fc;
+	EMailSession *session;
 
-	g_return_if_fail (E_IS_MAIL_SESSION (session));
+	g_return_if_fail (E_IS_MAIL_BACKEND (backend));
 
 	if (filter_editor) {
 		gtk_window_present (GTK_WINDOW (filter_editor));
@@ -287,6 +297,7 @@ em_utils_edit_filters (GtkWidget *parent,
 	}
 
 	config_dir = mail_session_get_config_dir ();
+	session = e_mail_backend_get_session (backend);
 
 	fc = em_filter_context_new (session);
 	user = g_build_filename (config_dir, "filters.xml", NULL);
@@ -296,8 +307,9 @@ em_utils_edit_filters (GtkWidget *parent,
 	g_free (system);
 
 	if (((ERuleContext *) fc)->error) {
-		GtkWidget *w = e_alert_dialog_new_for_args ((GtkWindow *)parent, "mail:filter-load-error", ((ERuleContext *)fc)->error, NULL);
-		em_utils_show_error_silent (w);
+		e_mail_backend_submit_alert (
+			backend, "mail:filter-load-error",
+			((ERuleContext *)fc)->error, NULL);
 		return;
 	}
 
@@ -973,7 +985,7 @@ em_utils_folder_is_templates (CamelFolder *folder, const gchar *uri)
 	gchar *templates_uri;
 
 	local_templates_folder =
-		e_mail_local_get_folder (E_MAIL_FOLDER_TEMPLATES);
+		e_mail_local_get_folder (E_MAIL_LOCAL_FOLDER_TEMPLATES);
 
 	if (folder == local_templates_folder)
 		return TRUE;
@@ -1027,7 +1039,7 @@ em_utils_folder_is_drafts (CamelFolder *folder, const gchar *uri)
 	gchar *drafts_uri;
 
 	local_drafts_folder =
-		e_mail_local_get_folder (E_MAIL_FOLDER_DRAFTS);
+		e_mail_local_get_folder (E_MAIL_LOCAL_FOLDER_DRAFTS);
 
 	if (folder == local_drafts_folder)
 		return TRUE;
@@ -1080,7 +1092,7 @@ em_utils_folder_is_sent (CamelFolder *folder, const gchar *uri)
 	gint is = FALSE;
 	gchar *sent_uri;
 
-	local_sent_folder = e_mail_local_get_folder (E_MAIL_FOLDER_SENT);
+	local_sent_folder = e_mail_local_get_folder (E_MAIL_LOCAL_FOLDER_SENT);
 
 	if (folder == local_sent_folder)
 		return TRUE;
@@ -1129,9 +1141,9 @@ em_utils_folder_is_outbox (CamelFolder *folder, const gchar *uri)
 	const gchar *local_outbox_folder_uri;
 
 	local_outbox_folder =
-		e_mail_local_get_folder (E_MAIL_FOLDER_OUTBOX);
+		e_mail_local_get_folder (E_MAIL_LOCAL_FOLDER_OUTBOX);
 	local_outbox_folder_uri =
-		e_mail_local_get_folder_uri (E_MAIL_FOLDER_OUTBOX);
+		e_mail_local_get_folder_uri (E_MAIL_LOCAL_FOLDER_OUTBOX);
 
 	if (folder == local_outbox_folder)
 		return TRUE;
@@ -1148,6 +1160,69 @@ em_utils_folder_is_outbox (CamelFolder *folder, const gchar *uri)
 static EProxy *emu_proxy = NULL;
 static GStaticMutex emu_proxy_lock = G_STATIC_MUTEX_INIT;
 
+/* encode to string this way, because soup_uri_to_string doesn't include passwords */
+static gchar *
+suri_to_string (SoupURI *suri)
+{
+	GString *uri;
+	gchar *tmp;
+
+	if (!suri)
+		return NULL;
+
+	uri = g_string_sized_new (20);
+
+	if (suri->scheme)
+		g_string_append_printf (uri, "%s:", suri->scheme);
+	if (suri->host) {
+		g_string_append (uri, "//");
+		if (suri->user) {
+			tmp = soup_uri_encode (suri->user, ":/;#@?\\");
+			g_string_append (uri, tmp);
+			g_free (tmp);
+		}
+
+		if (suri->password) {
+			g_string_append_c (uri, ':');
+			tmp = soup_uri_encode (suri->password, ":/;#@?\\");
+			g_string_append (uri, tmp);
+			g_free (tmp);
+		}
+
+		if (suri->user || suri->password)
+			g_string_append_c (uri, '@');
+
+		if (strchr (suri->host, ':')) {
+			g_string_append_c (uri, '[');
+			g_string_append (uri, suri->host);
+			g_string_append_c (uri, ']');
+		} else {
+			tmp = soup_uri_encode (suri->host, ":/");
+			g_string_append (uri, tmp);
+			g_free (tmp);
+		}
+
+		if (suri->port && !soup_uri_uses_default_port (suri))
+			g_string_append_printf (uri, ":%d", suri->port);
+		if (!suri->path && (suri->query || suri->fragment))
+			g_string_append_c (uri, '/');
+	}
+
+	if (suri->path && *suri->path)
+		g_string_append (uri, suri->path);
+
+	if (suri->query) {
+		g_string_append_c (uri, '?');
+		g_string_append (uri, suri->query);
+	}
+	if (suri->fragment) {
+		g_string_append_c (uri, '#');
+		g_string_append (uri, suri->fragment);
+	}
+
+	return g_string_free (uri, FALSE);
+}
+
 static gpointer
 emu_proxy_setup (gpointer data)
 {
@@ -1179,7 +1254,7 @@ em_utils_get_proxy_uri (const gchar *pUri)
 	}
 
 	if (e_proxy_require_proxy_for_uri (emu_proxy, pUri))
-		uri = soup_uri_to_string (e_proxy_peek_uri_for (emu_proxy, pUri), FALSE);
+		uri = suri_to_string (e_proxy_peek_uri_for (emu_proxy, pUri));
 
 	g_static_mutex_unlock (&emu_proxy_lock);
 
@@ -1262,12 +1337,13 @@ em_utils_message_to_html (CamelMimeMessage *message,
 /**
  * em_utils_expunge_folder:
  * @parent: parent window
+ * @session: #EMailSession
  * @folder: folder to expunge
  *
  * Expunges @folder.
  **/
 void
-em_utils_expunge_folder (GtkWidget *parent, CamelFolder *folder)
+em_utils_expunge_folder (GtkWidget *parent, EMailSession *session, CamelFolder *folder)
 {
 	const gchar *description;
 
@@ -1279,7 +1355,7 @@ em_utils_expunge_folder (GtkWidget *parent, CamelFolder *folder)
 		"mail:ask-expunge", description, NULL))
 		return;
 
-	mail_expunge_folder (folder, NULL, NULL);
+	mail_expunge_folder (session, folder, NULL, NULL);
 }
 
 /**
@@ -1385,7 +1461,7 @@ gchar *em_uri_from_camel (const gchar *curi)
 
 	if (strcmp(curl->protocol, "vfolder") == 0)
 		uid = "vfolder@local";
-	else if ((account = mail_config_get_account_by_source_url (curi)) == NULL)
+	else if ((account = e_get_account_by_source_url (curi)) == NULL)
 		uid = "local@local";
 	else
 		uid = account->uid;
@@ -1437,7 +1513,7 @@ gchar *em_uri_to_camel (const gchar *euri)
 			if (strcmp(eurl->user, "vfolder") == 0)
 				curl = camel_url_new("vfolder:", NULL);
 			else
-				curl = camel_url_new("mbox:", NULL);
+				curl = camel_url_new("maildir:", NULL);
 
 			base = g_strdup_printf("%s/mail/%s", e_get_user_data_dir(), eurl->user);
 #ifdef G_OS_WIN32
@@ -2025,48 +2101,6 @@ em_utils_clear_get_password_canceled_accounts_flag (void)
 	}
 }
 
-void
-em_utils_show_error_silent (GtkWidget *widget)
-{
-	EShell *shell;
-	EShellBackend *shell_backend;
-	EActivity *activity;
-
-	shell = e_shell_get_default ();
-	shell_backend = e_shell_get_backend_by_name (
-		shell, shell_builtin_backend);
-
-	activity = e_alert_activity_new_warning (widget);
-	e_shell_backend_add_activity (shell_backend, activity);
-	g_object_unref (activity);
-
-	if (g_object_get_data (G_OBJECT (widget), "response-handled") == NULL)
-		g_signal_connect (
-			widget, "response",
-			G_CALLBACK (gtk_widget_destroy), NULL);
-}
-
-void
-em_utils_show_info_silent (GtkWidget *widget)
-{
-	EShell *shell;
-	EShellBackend *shell_backend;
-	EActivity *activity;
-
-	shell = e_shell_get_default ();
-	shell_backend = e_shell_get_backend_by_name (
-		shell, shell_builtin_backend);
-
-	activity = e_alert_activity_new_info (widget);
-	e_shell_backend_add_activity (shell_backend, activity);
-	g_object_unref (activity);
-
-	if (g_object_get_data (G_OBJECT (widget), "response-handled") == NULL)
-		g_signal_connect (
-			widget, "response",
-			G_CALLBACK (gtk_widget_destroy), NULL);
-}
-
 gchar *
 em_utils_url_unescape_amp (const gchar *url)
 {
@@ -2110,7 +2144,7 @@ guess_account_from_folder (CamelFolder *folder)
 	service = CAMEL_SERVICE (parent_store);
 
 	source_url = camel_url_to_string (service->url, CAMEL_URL_HIDE_ALL);
-	account = mail_config_get_account_by_source_url (source_url);
+	account = e_get_account_by_source_url (source_url);
 	g_free (source_url);
 
 	return account;
@@ -2125,7 +2159,7 @@ guess_account_from_message (CamelMimeMessage *message)
 	if (source_url == NULL)
 		return NULL;
 
-	return mail_config_get_account_by_source_url (source_url);
+	return e_get_account_by_source_url (source_url);
 }
 
 GHashTable *
