@@ -43,9 +43,6 @@
 #include <e-util/e-extensible.h>
 #include "e-calendar.h"
 
-/* backward-compatibility cruft */
-#include "e-util/gtk-compat.h"
-
 #define E_DATE_EDIT_GET_PRIVATE(obj) \
 	(G_TYPE_INSTANCE_GET_PRIVATE \
 	((obj), E_TYPE_DATE_EDIT, EDateEditPrivate))
@@ -571,8 +568,9 @@ create_children			(EDateEdit	*dedit)
 		"widget \"*.e-dateedit-timecombo\" style \"e-dateedit-timecombo-style\"");
 
 	time_store = gtk_list_store_new (1, G_TYPE_STRING);
-	priv->time_combo = gtk_combo_box_entry_new_with_model (
-		GTK_TREE_MODEL (time_store), 0);
+	priv->time_combo = gtk_combo_box_new_with_model_and_entry (
+		GTK_TREE_MODEL (time_store));
+	gtk_combo_box_set_entry_text_column (GTK_COMBO_BOX (priv->time_combo), 0);
 	g_object_unref (time_store);
 
 	child = gtk_bin_get_child (GTK_BIN (priv->time_combo));
@@ -643,7 +641,7 @@ create_children			(EDateEdit	*dedit)
 
 	vbox = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (frame), vbox);
-        gtk_widget_show (vbox);
+	gtk_widget_show (vbox);
 
 	priv->calendar = e_calendar_new ();
 	calendar = E_CALENDAR (priv->calendar);
@@ -657,23 +655,23 @@ create_children			(EDateEdit	*dedit)
 			  G_CALLBACK (on_date_popup_date_selected), dedit);
 
 	gtk_box_pack_start (GTK_BOX (vbox), priv->calendar, FALSE, FALSE, 0);
-        gtk_widget_show (priv->calendar);
+	gtk_widget_show (priv->calendar);
 
 	bbox = gtk_hbutton_box_new ();
 	gtk_container_set_border_width (GTK_CONTAINER (bbox), 4);
 	gtk_box_set_spacing (GTK_BOX (bbox), 2);
 	gtk_box_pack_start (GTK_BOX (vbox), bbox, FALSE, FALSE, 0);
-        gtk_widget_show (bbox);
+	gtk_widget_show (bbox);
 
 	priv->now_button = gtk_button_new_with_mnemonic (_("No_w"));
 	gtk_container_add (GTK_CONTAINER (bbox), priv->now_button);
-        gtk_widget_show (priv->now_button);
+	gtk_widget_show (priv->now_button);
 	g_signal_connect (priv->now_button, "clicked",
 			  G_CALLBACK (on_date_popup_now_button_clicked), dedit);
 
 	priv->today_button = gtk_button_new_with_mnemonic (_("_Today"));
 	gtk_container_add (GTK_CONTAINER (bbox), priv->today_button);
-        gtk_widget_show (priv->today_button);
+	gtk_widget_show (priv->today_button);
 	g_signal_connect (priv->today_button, "clicked",
 			  G_CALLBACK (on_date_popup_today_button_clicked), dedit);
 
@@ -1402,12 +1400,12 @@ position_date_popup		(EDateEdit	*dedit)
 	GtkRequisition cal_req, button_req;
 	gint screen_width, screen_height;
 
-	gtk_widget_size_request (dedit->priv->cal_popup, &cal_req);
+	gtk_widget_get_preferred_size (dedit->priv->cal_popup, &cal_req, NULL);
 
-	gtk_widget_size_request (dedit->priv->date_button, &button_req);
+	gtk_widget_get_preferred_size (dedit->priv->date_button, &button_req, NULL);
 	bwidth = button_req.width;
-	gtk_widget_size_request (
-		gtk_widget_get_parent (dedit->priv->date_button), &button_req);
+	gtk_widget_get_preferred_size (
+		gtk_widget_get_parent (dedit->priv->date_button), &button_req, NULL);
 	bheight = button_req.height;
 
 	gtk_widget_translate_coordinates (
@@ -1572,16 +1570,18 @@ static void
 rebuild_time_popup			(EDateEdit	*dedit)
 {
 	EDateEditPrivate *priv;
-	GtkComboBox *combo;
+	GtkTreeModel *model;
+	GtkListStore *list_store;
+	GtkTreeIter iter;
 	gchar buffer[40];
 	struct tm tmp_tm;
 	gint hour, min;
 
 	priv = dedit->priv;
 
-	combo = GTK_COMBO_BOX (priv->time_combo);
-
-	gtk_list_store_clear (GTK_LIST_STORE (gtk_combo_box_get_model (combo)));
+	model = gtk_combo_box_get_model (GTK_COMBO_BOX (priv->time_combo));
+	list_store = GTK_LIST_STORE (model);
+	gtk_list_store_clear (list_store);
 
 	/* Fill the struct tm with some sane values. */
 	tmp_tm.tm_year = 2000;
@@ -1624,7 +1624,8 @@ rebuild_time_popup			(EDateEdit	*dedit)
 			if (!priv->use_24_hour_format && buffer[0] == '0')
 				buffer[0] = ' ';
 
-			gtk_combo_box_append_text (combo, buffer);
+			gtk_list_store_append (list_store, &iter);
+			gtk_list_store_set (list_store, &iter, 0, buffer, -1);
 		}
 	}
 }
@@ -1802,8 +1803,8 @@ on_date_entry_focus_out			(GtkEntry	*entry,
 	GtkWidget *msg_dialog;
 
 	tmp_tm.tm_year = 0;
-        tmp_tm.tm_mon = 0;
-        tmp_tm.tm_mday = 0;
+	tmp_tm.tm_mon = 0;
+	tmp_tm.tm_mday = 0;
 
 	e_date_edit_check_date_changed (dedit);
 
