@@ -31,7 +31,7 @@
 #include <gtk/gtk.h>
 #include "e-cell-pixbuf.h"
 
-G_DEFINE_TYPE (ECellPixbuf, e_cell_pixbuf, E_CELL_TYPE)
+G_DEFINE_TYPE (ECellPixbuf, e_cell_pixbuf, E_TYPE_CELL)
 
 typedef struct _ECellPixbufView ECellPixbufView;
 
@@ -56,19 +56,7 @@ enum {
 ECell *
 e_cell_pixbuf_new (void)
 {
-    ECellPixbuf *ecp;
-
-    ecp = g_object_new (E_CELL_PIXBUF_TYPE, NULL);
-    e_cell_pixbuf_construct (ecp);
-
-    return (ECell *) ecp;
-}
-
-void
-e_cell_pixbuf_construct (ECellPixbuf *ecp)
-{
-    /* noop */
-    return;
+	return g_object_new (E_TYPE_CELL_PIXBUF, NULL);
 }
 
 /*
@@ -99,24 +87,23 @@ pixbuf_kill_view (ECellView *ecell_view)
     ECellPixbufView *pixbuf_view = (ECellPixbufView *) ecell_view;
 
     if (pixbuf_view->cell_view.kill_view_cb)
-        pixbuf_view->cell_view.kill_view_cb (
-            ecell_view, pixbuf_view->cell_view.kill_view_cb_data);
+	pixbuf_view->cell_view.kill_view_cb (
+	    ecell_view, pixbuf_view->cell_view.kill_view_cb_data);
 
     if (pixbuf_view->cell_view.kill_view_cb_data)
-        g_list_free (pixbuf_view->cell_view.kill_view_cb_data);
+	g_list_free (pixbuf_view->cell_view.kill_view_cb_data);
 
     g_free (pixbuf_view);
 }
 
 static void
-pixbuf_draw (ECellView *ecell_view, GdkDrawable *drawable,
+pixbuf_draw (ECellView *ecell_view, cairo_t *cr,
              gint model_col, gint view_col, gint row, ECellFlags flags,
              gint x1, gint y1, gint x2, gint y2)
 {
     GdkPixbuf *cell_pixbuf;
     gint real_x, real_y;
     gint pix_w, pix_h;
-    cairo_t *cr;
 
     cell_pixbuf = e_table_model_value_at (ecell_view->e_table_model,
 							  1, row);
@@ -124,7 +111,7 @@ pixbuf_draw (ECellView *ecell_view, GdkDrawable *drawable,
     /* we can't make sure we really got a pixbuf since, well, it's a Gdk thing */
 
     if (x2 - x1 == 0)
-        return;
+	return;
 
     if (!cell_pixbuf)
 	return;
@@ -134,25 +121,23 @@ pixbuf_draw (ECellView *ecell_view, GdkDrawable *drawable,
 
     /* We center the pixbuf within our allocated space */
     if (x2 - x1 > pix_w) {
-        gint diff = (x2 - x1) - pix_w;
-        real_x = x1 + diff/2;
+	gint diff = (x2 - x1) - pix_w;
+	real_x = x1 + diff/2;
     } else {
-        real_x = x1;
+	real_x = x1;
     }
 
     if (y2 - y1 > pix_h) {
-        gint diff = (y2 - y1) - pix_h;
-        real_y = y1 + diff/2;
+	gint diff = (y2 - y1) - pix_h;
+	real_y = y1 + diff/2;
     } else {
-        real_y = y1;
+	real_y = y1;
     }
 
-    cr = gdk_cairo_create (drawable);
     cairo_save (cr);
     gdk_cairo_set_source_pixbuf (cr, cell_pixbuf, real_x, real_y);
     cairo_paint_with_alpha (cr, 1);
     cairo_restore (cr);
-    cairo_destroy (cr);
 }
 
 static gint
@@ -171,7 +156,7 @@ pixbuf_height (ECellView *ecell_view, gint model_col, gint view_col, gint row)
     GdkPixbuf *pixbuf;
     if (row == -1) {
       if (e_table_model_row_count (ecell_view->e_table_model) > 0) {
-        row = 0;
+	row = 0;
       } else {
 	return 6;
       }
@@ -179,7 +164,7 @@ pixbuf_height (ECellView *ecell_view, gint model_col, gint view_col, gint row)
 
     pixbuf = (GdkPixbuf *) e_table_model_value_at (ecell_view->e_table_model, 1, row);
     if (!pixbuf)
-        return 0;
+	return 0;
 
     /* We give ourselves 3 pixels of padding on either side */
     return gdk_pixbuf_get_height (pixbuf) + 6;
@@ -240,21 +225,21 @@ pixbuf_max_width (ECellView *ecell_view, gint model_col, gint view_col)
     gint max_width = -1;
 
     if (model_col == 0) {
-        num_rows = e_table_model_row_count (ecell_view->e_table_model);
+	num_rows = e_table_model_row_count (ecell_view->e_table_model);
 
-        for (i = 0; i <= num_rows; i++) {
-            GdkPixbuf *pixbuf = (GdkPixbuf *) e_table_model_value_at
-                (ecell_view->e_table_model,
-                 1,
-                 i);
-           if (!pixbuf)
-               continue;
-            pw = gdk_pixbuf_get_width (pixbuf);
-            if (max_width < pw)
-                max_width = pw;
-        }
+	for (i = 0; i <= num_rows; i++) {
+	    GdkPixbuf *pixbuf = (GdkPixbuf *) e_table_model_value_at
+		(ecell_view->e_table_model,
+		 1,
+		 i);
+	   if (!pixbuf)
+	       continue;
+	    pw = gdk_pixbuf_get_width (pixbuf);
+	    if (max_width < pw)
+		max_width = pw;
+	}
     } else {
-        return -1;
+	return -1;
     }
 
     return max_width;
@@ -334,10 +319,10 @@ e_cell_pixbuf_init (ECellPixbuf *ecp)
 }
 
 static void
-e_cell_pixbuf_class_init (ECellPixbufClass *klass)
+e_cell_pixbuf_class_init (ECellPixbufClass *class)
 {
-	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	ECellClass *ecc = E_CELL_CLASS (klass);
+	GObjectClass *object_class = G_OBJECT_CLASS (class);
+	ECellClass *ecc = E_CELL_CLASS (class);
 
 	object_class->dispose = pixbuf_dispose;
 	object_class->set_property = pixbuf_set_property;
