@@ -41,9 +41,6 @@
 #include "e-table-item.h"
 #include <gtk/gtk.h>
 
-/* backward-compatibility cruft */
-#include "e-util/gtk-compat.h"
-
 #define E_CELL_POPUP_ARROW_WIDTH	16
 #define E_CELL_POPUP_ARROW_XPAD		3
 #define E_CELL_POPUP_ARROW_YPAD		3
@@ -57,7 +54,7 @@ static void	ecp_kill_view		(ECellView	*ecv);
 static void	ecp_realize		(ECellView	*ecv);
 static void	ecp_unrealize		(ECellView	*ecv);
 static void	ecp_draw		(ECellView	*ecv,
-					 GdkDrawable	*drawable,
+					 cairo_t	*cr,
 					 gint		 model_col,
 					 gint		 view_col,
 					 gint		 row,
@@ -109,14 +106,14 @@ static gint e_cell_popup_do_popup	(ECellPopupView	*ecp_view,
 					 gint             row,
 					 gint             model_col);
 
-G_DEFINE_TYPE (ECellPopup, e_cell_popup, E_CELL_TYPE)
+G_DEFINE_TYPE (ECellPopup, e_cell_popup, E_TYPE_CELL)
 
 static void
-e_cell_popup_class_init		(ECellPopupClass	*klass)
+e_cell_popup_class_init		(ECellPopupClass	*class)
 {
-	ECellClass *ecc = E_CELL_CLASS (klass);
+	ECellClass *ecc = E_CELL_CLASS (class);
 
-	G_OBJECT_CLASS (klass)->dispose = e_cell_popup_dispose;
+	G_OBJECT_CLASS (class)->dispose = e_cell_popup_dispose;
 
 	ecc->new_view     = ecp_new_view;
 	ecc->kill_view    = ecp_kill_view;
@@ -133,8 +130,8 @@ e_cell_popup_class_init		(ECellPopupClass	*klass)
 	ecc->get_bg_color = ecp_get_bg_color;
 
 	gal_a11y_e_cell_registry_add_cell_type (NULL,
-                                                E_CELL_POPUP_TYPE,
-                                                gal_a11y_e_cell_popup_new);
+						E_TYPE_CELL_POPUP,
+						gal_a11y_e_cell_popup_new);
 }
 
 static void
@@ -152,11 +149,9 @@ e_cell_popup_init		(ECellPopup	*ecp)
  * Returns: an ECellPopup object.
  */
 ECell *
-e_cell_popup_new		(void)
+e_cell_popup_new (void)
 {
-	ECellPopup *ecp = g_object_new (E_CELL_POPUP_TYPE, NULL);
-
-	return (ECell*) ecp;
+	return g_object_new (E_TYPE_CELL_POPUP, NULL);
 }
 
 static void
@@ -188,8 +183,8 @@ ecp_new_view (ECell *ecell, ETableModel *table_model, gpointer e_table_item_view
 	ecp_view->cell_view.ecell = ecell;
 	ecp_view->cell_view.e_table_model = table_model;
 	ecp_view->cell_view.e_table_item_view = e_table_item_view;
-        ecp_view->cell_view.kill_view_cb = NULL;
-        ecp_view->cell_view.kill_view_cb_data = NULL;
+	ecp_view->cell_view.kill_view_cb = NULL;
+	ecp_view->cell_view.kill_view_cb_data = NULL;
 
 	ecp_view->child_view = e_cell_new_view (ecp->child, table_model,
 						e_table_item_view);
@@ -250,7 +245,7 @@ ecp_unrealize (ECellView *ecv)
  * ECell::draw method
  */
 static void
-ecp_draw (ECellView *ecv, GdkDrawable *drawable,
+ecp_draw (ECellView *ecv, cairo_t *cr,
 	  gint model_col, gint view_col, gint row, ECellFlags flags,
 	  gint x1, gint y1, gint x2, gint y2)
 {
@@ -261,6 +256,8 @@ ecp_draw (ECellView *ecv, GdkDrawable *drawable,
 	GdkRectangle rect;
 	gboolean show_popup_arrow;
 
+	cairo_save (cr);
+
 	canvas = GTK_WIDGET (GNOME_CANVAS_ITEM (ecv->e_table_item_view)->canvas);
 
 	/* Display the popup arrow if we are the cursor cell, or the popup
@@ -279,7 +276,7 @@ ecp_draw (ECellView *ecv, GdkDrawable *drawable,
 	if (show_popup_arrow) {
 		GtkStyle *style;
 
-		e_cell_draw (ecp_view->child_view, drawable, model_col,
+		e_cell_draw (ecp_view->child_view, cr, model_col,
 			     view_col, row, flags,
 			     x1, y1, x2 - E_CELL_POPUP_ARROW_WIDTH, y2);
 
@@ -295,22 +292,24 @@ ecp_draw (ECellView *ecv, GdkDrawable *drawable,
 
 		style = gtk_widget_get_style (canvas);
 
-		gtk_paint_box (style, drawable,
+		gtk_paint_box (style, cr,
 			       GTK_STATE_NORMAL, shadow,
-			       &rect, canvas, "ecellpopup",
+			       canvas, "ecellpopup",
 			       rect.x, rect.y, rect.width, rect.height);
-		gtk_paint_arrow (style, drawable,
+		gtk_paint_arrow (style, cr,
 				 GTK_STATE_NORMAL, GTK_SHADOW_NONE,
-				 &rect, canvas, NULL,
+				 canvas, NULL,
 				 GTK_ARROW_DOWN, TRUE,
 				 rect.x + E_CELL_POPUP_ARROW_XPAD,
 				 rect.y + E_CELL_POPUP_ARROW_YPAD,
 				 rect.width - E_CELL_POPUP_ARROW_XPAD * 2,
 				 rect.height - E_CELL_POPUP_ARROW_YPAD * 2);
 	} else {
-		e_cell_draw (ecp_view->child_view, drawable, model_col,
+		e_cell_draw (ecp_view->child_view, cr, model_col,
 			     view_col, row, flags, x1, y1, x2, y2);
 	}
+
+	cairo_restore (cr);
 }
 
 /*
@@ -461,7 +460,7 @@ e_cell_popup_do_popup			(ECellPopupView	*ecp_view,
 
 	ecp->popup_cell_view = ecp_view;
 
-	popup_func = E_CELL_POPUP_CLASS (GTK_OBJECT_GET_CLASS (ecp))->popup;
+	popup_func = E_CELL_POPUP_CLASS (G_OBJECT_GET_CLASS (ecp))->popup;
 
 	ecp->popup_view_col = view_col;
 	ecp->popup_row = row;
