@@ -56,9 +56,6 @@
 #include "e-cell-text.h"
 #include "e-table-item.h"
 
-/* backward-compatibility cruft */
-#include "e-util/gtk-compat.h"
-
 #define d(x)
 #define DO_SELECTION 1
 #define VIEW_TO_CELL(view) E_CELL_TEXT (((ECellView *)view)->ecell)
@@ -105,7 +102,7 @@ static guint signals[LAST_SIGNAL] = { 0 };
 
 static GdkAtom clipboard_atom = GDK_NONE;
 
-G_DEFINE_TYPE (ECellText, e_cell_text, E_CELL_TYPE)
+G_DEFINE_TYPE (ECellText, e_cell_text, E_TYPE_CELL)
 
 #define UTF8_ATOM  gdk_atom_intern ("UTF8_STRING", FALSE)
 
@@ -200,8 +197,6 @@ static void _get_tep (CellEdit *edit);
 static gint get_position_from_xy (CellEdit *edit, gint x, gint y);
 static gboolean _blink_scroll_timeout (gpointer data);
 
-static void ect_free_color (gchar *color_spec, GdkColor *color, GdkColormap *colormap);
-static GdkColor* e_cell_text_get_color (ECellTextView *cell_view, gchar *color_spec);
 static void e_cell_text_preedit_changed_cb (GtkIMContext *context, ECellTextView *text_view);
 static void e_cell_text_commit_cb (GtkIMContext *context, const gchar  *str, ECellTextView *text_view);
 static gboolean e_cell_text_retrieve_surrounding_cb (GtkIMContext *context, ECellTextView *text_view);
@@ -331,7 +326,7 @@ ect_new_view (ECell *ecell, ETableModel *table_model, gpointer e_table_item_view
 	text_view->cell_view.e_table_model = table_model;
 	text_view->cell_view.e_table_item_view = e_table_item_view;
 	text_view->cell_view.kill_view_cb = NULL;
-        text_view->cell_view.kill_view_cb_data = NULL;
+	text_view->cell_view.kill_view_cb_data = NULL;
 
 	text_view->canvas = canvas;
 
@@ -350,7 +345,7 @@ ect_kill_view (ECellView *ecv)
 	ECellTextView *text_view = (ECellTextView *) ecv;
 
 	if (text_view->cell_view.kill_view_cb)
-            (text_view->cell_view.kill_view_cb)(ecv, text_view->cell_view.kill_view_cb_data);
+	    (text_view->cell_view.kill_view_cb)(ecv, text_view->cell_view.kill_view_cb_data);
 
 	if (text_view->cell_view.kill_view_cb_data)
 	    g_list_free (text_view->cell_view.kill_view_cb_data);
@@ -382,43 +377,18 @@ static void
 ect_unrealize (ECellView *ecv)
 {
 	ECellTextView *text_view = (ECellTextView *) ecv;
-	ECellText *ect = (ECellText*) ecv->ecell;
-	GdkColormap *colormap;
 
 	if (text_view->edit) {
 		ect_cancel_edit (text_view);
 	}
 
-	gdk_cursor_unref (text_view->i_cursor);
-
-	if (ect->colors) {
-		colormap = gtk_widget_get_colormap (GTK_WIDGET (text_view->canvas));
-		g_hash_table_foreach (ect->colors, (GHFunc) ect_free_color,
-				      colormap);
-		g_hash_table_destroy (ect->colors);
-		ect->colors = NULL;
-	}
+	g_object_unref (text_view->i_cursor);
 
 	if (E_CELL_CLASS (e_cell_text_parent_class)->unrealize)
 		(* E_CELL_CLASS (e_cell_text_parent_class)->unrealize) (ecv);
 
 }
 
-static void
-ect_free_color (gchar *color_spec, GdkColor *color, GdkColormap *colormap)
-{
-	g_free (color_spec);
-
-	/* This frees the color. Note we don't free it if it is the special
-	   value. */
-	if (color != (GdkColor*) 1) {
-		gdk_colormap_free_colors (colormap, color, 1);
-
-		/* This frees the memory for the GdkColor. */
-		gdk_color_free (color);
-	}
-}
-
 static PangoAttrList*
 build_attr_list (ECellTextView *text_view, gint row, gint text_length)
 {
@@ -681,12 +651,21 @@ show_pango_rectangle (CellEdit *edit, PangoRectangle rect)
 }
 
 static gint
-get_vertical_spacing (GtkWidget *widget)
+get_vertical_spacing (GtkWidget *canvas)
 {
-	GtkStyle *style = gtk_rc_get_style (widget);
+	GtkStyle *style;
+	GtkWidget *widget;
 	gint vspacing = 0;
 
-	gtk_style_get (style, E_TABLE_TYPE, "vertical-spacing", &vspacing, NULL);
+	g_return_val_if_fail (E_IS_CANVAS (canvas), 3);
+
+	/* The parent should be either an ETable or ETree. */
+	widget = gtk_widget_get_parent (canvas);
+	style = gtk_widget_get_style (widget);
+
+	gtk_style_get (
+		style, G_OBJECT_TYPE (widget),
+		"vertical-spacing", &vspacing, NULL);
 
 	return vspacing;
 }
@@ -695,7 +674,7 @@ get_vertical_spacing (GtkWidget *widget)
  * ECell::draw method
  */
 static void
-ect_draw (ECellView *ecell_view, GdkDrawable *drawable,
+ect_draw (ECellView *ecell_view, cairo_t *cr,
 	  gint model_col, gint view_col, gint row, ECellFlags flags,
 	  gint x1, gint y1, gint x2, gint y2)
 {
@@ -707,14 +686,12 @@ ect_draw (ECellView *ecell_view, GdkDrawable *drawable,
 	GtkWidget *canvas = GTK_WIDGET (text_view->canvas);
 	GtkStyle *style;
 	gint x_origin, y_origin, vspacing;
-        cairo_t *cr;
 
+	cairo_save (cr);
 	style = gtk_widget_get_style (canvas);
 
 	selected = flags & E_CELL_SELECTED;
 
-        cr = gdk_cairo_create (drawable);
-
 	if (selected) {
 		if (gtk_widget_has_focus (canvas))
 			gdk_cairo_set_source_color (cr, &style->fg[GTK_STATE_SELECTED]);
@@ -725,14 +702,13 @@ ect_draw (ECellView *ecell_view, GdkDrawable *drawable,
 
 		if (ect->color_column != -1) {
 			gchar *color_spec;
-			GdkColor *cell_foreground;
+			GdkColor color;
 
-			color_spec = e_table_model_value_at (ecell_view->e_table_model,
-							     ect->color_column, row);
-			cell_foreground = e_cell_text_get_color (text_view,
-								 color_spec);
-			if (cell_foreground)
-				gdk_cairo_set_source_color (cr, cell_foreground);
+			color_spec = e_table_model_value_at (
+				ecell_view->e_table_model,
+				ect->color_column, row);
+			if (color_spec && gdk_color_parse (color_spec, &color))
+				gdk_cairo_set_source_color (cr, &color);
 		}
 	}
 
@@ -746,8 +722,8 @@ ect_draw (ECellView *ecell_view, GdkDrawable *drawable,
 	x_origin = x1 + ect->x + text_view->xofs - (edit ? edit->xofs_edit : 0);
 	y_origin = y1 + ect->y + text_view->yofs - (edit ? edit->yofs_edit : 0);
 
-        cairo_rectangle (cr, x1, y1, x2 - x1, y2 - y1);
-        cairo_clip (cr);
+	cairo_rectangle (cr, x1, y1, x2 - x1, y2 - y1);
+	cairo_clip (cr);
 
 	layout = generate_layout (text_view, model_col, view_col, row, x2 - x1);
 
@@ -755,33 +731,33 @@ ect_draw (ECellView *ecell_view, GdkDrawable *drawable,
 		layout = layout_with_preedit  (text_view, row, edit->text ? edit->text : "?",  x2 - x1);
 	}
 
-        cairo_move_to (cr, x_origin, y_origin);
+	cairo_move_to (cr, x_origin, y_origin);
 	pango_cairo_show_layout (cr, layout);
 
 	if (edit && edit->view_col == view_col && edit->row == row) {
 		if (edit->selection_start != edit->selection_end) {
-			GdkRegion *clip_region;
-                        gint indices[2];
-                        GtkStateType state;
+			cairo_region_t *clip_region;
+			gint indices[2];
+			GtkStateType state;
 
-                        state = edit->has_selection ? GTK_STATE_SELECTED : GTK_STATE_ACTIVE;
+			state = edit->has_selection ? GTK_STATE_SELECTED : GTK_STATE_ACTIVE;
 
 			indices[0] = MIN (edit->selection_start, edit->selection_end);
 			indices[1] = MAX (edit->selection_start, edit->selection_end);
 
-                        clip_region = gdk_pango_layout_get_clip_region (layout,
-                                                                        x_origin, y_origin,
-                                                                        indices, 1);
-                        gdk_cairo_region (cr, clip_region);
-                        cairo_clip (cr);
-			gdk_region_destroy (clip_region);
+			clip_region = gdk_pango_layout_get_clip_region (layout,
+									x_origin, y_origin,
+									indices, 1);
+			gdk_cairo_region (cr, clip_region);
+			cairo_clip (cr);
+			cairo_region_destroy (clip_region);
 
-                        gdk_cairo_set_source_color (cr, &style->base[state]);
-                        cairo_paint (cr);
+			gdk_cairo_set_source_color (cr, &style->base[state]);
+			cairo_paint (cr);
 
-                        gdk_cairo_set_source_color (cr, &style->text[state]);
-                        cairo_move_to (cr, x_origin, y_origin);
-                        pango_cairo_show_layout (cr, layout);
+			gdk_cairo_set_source_color (cr, &style->text[state]);
+			cairo_move_to (cr, x_origin, y_origin);
+			pango_cairo_show_layout (cr, layout);
 		} else {
 			if (edit->show_cursor) {
 				PangoRectangle strong_pos, weak_pos;
@@ -798,7 +774,7 @@ ect_draw (ECellView *ecell_view, GdkDrawable *drawable,
 	}
 
 	g_object_unref (layout);
-        cairo_destroy (cr);
+	cairo_restore (cr);
 }
 
 /*
@@ -1143,7 +1119,7 @@ ect_enter_edit (ECellView *ecell_view, gint model_col, gint view_col, gint row)
 		}
 		gtk_im_context_focus_in (edit->im_context);
 	}
-	
+
 #if 0
 	if (edit->pointer_in) {
 		if (edit->default_cursor_shown) {
@@ -1517,10 +1493,10 @@ static gchar *ellipsis_default = NULL;
 static gboolean use_ellipsis_default = TRUE;
 
 static void
-e_cell_text_class_init (ECellTextClass *klass)
+e_cell_text_class_init (ECellTextClass *class)
 {
-	ECellClass *ecc = E_CELL_CLASS (klass);
-	GObjectClass *object_class = G_OBJECT_CLASS (klass);
+	ECellClass *ecc = E_CELL_CLASS (class);
+	GObjectClass *object_class = G_OBJECT_CLASS (class);
 	const gchar *ellipsis_env;
 
 	object_class->finalize = ect_finalize;
@@ -1543,9 +1519,9 @@ e_cell_text_class_init (ECellTextClass *klass)
 	ecc->max_width_by_row = ect_max_width_by_row;
 	ecc->get_bg_color = ect_get_bg_color;
 
-	klass->get_text = ect_real_get_text;
-	klass->free_text = ect_real_free_text;
-	klass->set_value = ect_real_set_value;
+	class->get_text = ect_real_get_text;
+	class->free_text = ect_real_free_text;
+	class->set_value = ect_real_set_value;
 
 	object_class->get_property = ect_get_property;
 	object_class->set_property = ect_set_property;
@@ -2467,45 +2443,6 @@ _get_tep (CellEdit *edit)
 	}
 }
 
-static GdkColor*
-e_cell_text_get_color (ECellTextView *cell_view, gchar *color_spec)
-{
-	ECellText *ect = E_CELL_TEXT (((ECellView*) cell_view)->ecell);
-	GdkColormap *colormap;
-	GdkColor *color, tmp_color;
-
-	/* If the color spec is NULL we use the default color. */
-	if (color_spec == NULL)
-		return NULL;
-
-	/* Create the hash table if we haven't already. */
-	if (!ect->colors)
-		ect->colors = g_hash_table_new (g_str_hash, g_str_equal);
-
-	/* See if we've already allocated the color. Note that we use a
-	   special value of (GdkColor*) 1 in the hash to indicate that we've
-	   already tried and failed to allocate the color, so we don't keep
-	   trying to allocate it. */
-	color = g_hash_table_lookup (ect->colors, color_spec);
-	if (color == (GdkColor*) 1)
-		return NULL;
-	if (color)
-		return color;
-
-	/* Try to parse the color. */
-	if (gdk_color_parse (color_spec, &tmp_color)) {
-		colormap = gtk_widget_get_colormap (GTK_WIDGET (cell_view->canvas));
-
-		/* Try to allocate the color. */
-		if (gdk_colormap_alloc_color (colormap, &tmp_color, FALSE, TRUE))
-			color = gdk_color_copy (&tmp_color);
-	}
-
-	g_hash_table_insert (ect->colors, g_strdup (color_spec),
-			     color ? color : (GdkColor*) 1);
-	return color;
-}
-
 /**
  * e_cell_text_set_selection:
  * @cell_view: the given cell view
